@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.10 2001/01/15 13:43:46 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.11 2001/01/26 10:19:22 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -645,6 +645,7 @@ static int ip_vs_bypass_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
+	skb->nfmark = NFMARK_IPVS_PROPERTY;
         ip_send(skb);
 
         LeaveFunction(10);
@@ -689,9 +690,9 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 	u32    rtos;
 	union ip_vs_tphdr h;
 	unsigned short size;
-	int doff;
-	int csum = 0;
-	int csum_ok = 0;
+	int doff;                       /* transport protocol data offset */
+	int csum = 0;                   /* checksum */
+	int csum_ok = 0;                /* csum_ok says if csum is valid */
         int mtu;
 
 	EnterFunction(10);
@@ -796,10 +797,8 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
         /*
          * Yug! adjust UDP/TCP checksums
          */
-        /*
-         *	Transport's payload partial csum
-         */
         if (!csum_ok) {
+                /* Transport's payload partial checksum */
                 csum = csum_partial(h.raw + doff, size - doff, 0);
         }
         skb->csum = csum;
@@ -835,6 +834,7 @@ static int ip_vs_nat_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
+	skb->nfmark = NFMARK_IPVS_PROPERTY;
         ip_send(skb);
 
         LeaveFunction(10);
@@ -972,6 +972,7 @@ static int ip_vs_tunnel_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
+	skb->nfmark = NFMARK_IPVS_PROPERTY;
 	ip_send(skb);
 
         LeaveFunction(10);
@@ -1033,6 +1034,7 @@ static int ip_vs_dr_xmit(struct sk_buff *skb, struct ip_vs_conn *cp)
 #ifdef CONFIG_NETFILTER_DEBUG
         skb->nf_debug = 1 << NF_IP_LOCAL_OUT;
 #endif /* CONFIG_NETFILTER_DEBUG */
+	skb->nfmark = NFMARK_IPVS_PROPERTY;
         ip_send(skb);
 
 #if 0000
