@@ -2,7 +2,7 @@
  *      ipvsadm - IP Virtual Server ADMinistration program
  *                for IPVS NetFilter Module in kernel 2.4
  *
- *      Version: $Id: ipvsadm.c,v 1.5 2001/01/11 14:14:59 wensong Exp $
+ *      Version: $Id: ipvsadm.c,v 1.6 2001/02/15 15:12:16 wensong Exp $
  *
  *      Authors: Wensong Zhang <wensong@linuxvirtualserver.org>
  *               Peter Kese <peter.kese@ijs.si>
@@ -1122,16 +1122,16 @@ void usage_exit(const char *program, const int exit_status) {
 	version(stream);
         fprintf(stream,
                 "Usage:\n"
-                "  %s -[A|E] -[t|u|f] service-address [-s scheduler] [-p [timeout]] [-M netmask]\n"
-                "  %s -D -[t|u|f] service-address\n"
+                "  %s -A|E -t|u|f service-address [-s scheduler] [-p [timeout]] [-M netmask]\n"
+                "  %s -D -t|u|f service-address\n"
                 "  %s -C\n"
 #ifdef HAVE_POPT
                 "  %s -R\n"
                 "  %s -S [-n]\n"
 #endif
-                "  %s -[a|e] -[t|u|f] service-address -[r|R] server-address [-g|-i|-m] [-w weight]\n"
-                "  %s -d -[t|u|f] service-address -[r|R] server-address\n"
-                "  %s -[L|l] [-n]\n"
+                "  %s -a|e -t|u|f service-address -r|R server-address [-g|i|m] [-w weight]\n"
+                "  %s -d -t|u|f service-address -r|R server-address\n"
+                "  %s -L|l [-c] [-n]\n"
                 "  %s -s tcp tcpfin udp\n"
                 "  %s -h\n\n",
 #ifdef HAVE_POPT
@@ -1164,15 +1164,16 @@ void usage_exit(const char *program, const int exit_status) {
                 "  --tcp-service  -t service-address   service-address is host[:port]\n"
                 "  --udp-service  -u service-address   service-address is host[:port]\n"
                 "  --fwmark-service  -f fwmark         fwmark is an integer greater than zero\n"
-                "  --scheduler    -s <scheduler>       one of rr|wrr|lc|wlc|lblc,\n"
+                "  --scheduler    -s scheduler         one of " SCHEDULERS ",\n"
                 "                                      the default scheduler is %s.\n"
                 "  --persistent   -p [timeout]         persistent service\n"
-                "  --netmask      -M [netmask]         persistent granularity mask\n"
-                "  --real-server  -r|-R server-address server-address is host (and port)\n"
+                "  --netmask      -M netmask           persistent granularity mask\n"
+                "  --real-server  -r|R server-address server-address is host (and port)\n"
                 "  --gatewaying   -g                   gatewaying (direct routing) (default)\n"
                 "  --ipip         -i                   ipip encapsulation (tunneling)\n"
                 "  --masquerading -m                   masquerading (NAT)\n"
-                "  --weight       -w <weight>          capacity of real server\n"
+                "  --weight       -w weight            capacity of real server\n"
+                "  --connection   -c                   output of current IPVS connections\n"
                 "  --numeric      -n                   numeric output of addresses and ports\n",
                 DEF_SCHED);
         
